@@ -42,6 +42,11 @@ def _display(obj, *args):
 class Test(unittest.TestCase):
 
     def setUp(self):
+        # Save the original environment, then force a fixed column width
+        # so tests do not fail on some platforms (notably, OSX)
+        self.original_environ = dict(os.environ)
+        os.environ["COLUMNS"] = "80"
+
         self.config = config = ConfigBlock(
             "Basic configuration for Flushing models", implicit=True)
         net = config.declare('network', ConfigBlock())
@@ -148,6 +153,9 @@ class Test(unittest.TestCase):
                 },
             },
         }
+    def tearDown(self):
+        # Restore the original environment
+        os.environ = self.original_environ
 
     # Utility method for generating and validating a template description
     def _validateTemplate(self, config, reference_template, **kwds):
@@ -892,7 +900,7 @@ scenario.foo""")
         test = self.config.generate_documentation()
         OUTPUT.write(test)
         OUTPUT.close()
-        print(test)
+        #print(test)
         self.assertFalse(
             pyutilib.misc.comparison.compare_file(oFile, oFile[:-4] + '.txt')[
                 0])
@@ -1011,7 +1019,7 @@ endBlock{}
             item_body=   "item{%s}\n",
             item_end=    "endItem{%s}\n",
         )
-        print(test)
+        #print(test)
         self.assertEqual(test, reference)
 
         test = self.config.generate_documentation(
@@ -1027,7 +1035,7 @@ endBlock{}
             stripped_reference = re.sub('\{[^\}]*\}','',reference)
         else:
             stripped_reference = re.sub('\{[^\}]*\}','',reference,flags=re.M)
-        print(test)
+        #print(test)
         self.assertEqual(test, stripped_reference)
 
     def test_block_get(self):
@@ -1165,7 +1173,7 @@ endBlock{}
         self.assertFalse(itemiter is self.config['scenario'].iteritems())
 
     def test_value(self):
-        print(self.config.value())
+        #print(self.config.value())
         self.assertEqual(self._reference, self.config.value())
 
     def test_list_manipulation(self):
@@ -1283,7 +1291,7 @@ endBlock{}
         parser = argparse.ArgumentParser(prog='tester')
         self.config.initialize_argparse(parser)
         help = parser.format_help()
-        print(help)
+        #print(help)
         self.assertEqual(
             """usage: tester [-h] [--epanet-file EPANET] [--scenario-file STR] [--merlion]
 
@@ -1308,7 +1316,8 @@ Scenario definition:
         parser = argparse.ArgumentParser(prog='tester')
         self.config.initialize_argparse(parser)
         help = parser.format_help()
-        print(help)
+        #print(help)
+        self.maxDiff = None
         self.assertEqual(
             """usage: tester [-h] [--epanet-file EPANET] [--scenario-file STR] [--merlion]
               [--disable-epanet]
@@ -1380,7 +1389,7 @@ Scenario definition:
         self.config.initialize_argparse(parser)
 
         help = parser.format_help()
-        print(help)
+        #print(help)
         self.assertEqual(
             """usage: tester [-h] [--epanet-file EPANET] [--scenario-file STR] [--merlion]
               {flushing} ...
@@ -1399,7 +1408,7 @@ Scenario definition:
 """, help)
 
         help = subp.format_help()
-        print(help)
+        #print(help)
         self.assertEqual(
             """usage: tester flushing [-h] [--feasible-nodes STR] [--infeasible-nodes STR]
                        [--duration FLOAT]
